@@ -47,10 +47,7 @@ fn test_inner_html_patch() {
         patch,
         vec![AddAttributes::new(
             &"article",
-            PatchPath::new(
-                TreePath::start_at(1, vec![0, 0]),
-                TreePath::start_at(1, vec![0, 0])
-            ),
+            TreePath::start_at(1, vec![0, 0]),
             vec![&inner_html("<h1>Lorep Ipsum</h1>")]
         )
         .into()]
@@ -72,10 +69,7 @@ fn test_inner_html_removed() {
         patch,
         vec![RemoveAttributes::new(
             &"article",
-            PatchPath::new(
-                TreePath::start_at(1, vec![0, 0]),
-                TreePath::start_at(1, vec![0, 0])
-            ),
+            TreePath::start_at(1, vec![0, 0]),
             vec![&inner_html("<h1>Lorep Ipsum</h1>")]
         )
         .into()]
